@@ -1,32 +1,20 @@
 /*
-    Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+    SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
 
     Based on MailTransport code by:
-    Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2006 - 2007 Volker Krause <vkrause@kde.org>
 
     Based on KMail code by:
-    Copyright (c) 2001-2002 Michael Haeckel <haeckel@kde.org>
+    SPDX-FileCopyrightText: 2001-2002 Michael Haeckel <haeckel@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef MAILTRANSPORT_TRANSPORTCONFIGWIDGET_H
 #define MAILTRANSPORT_TRANSPORTCONFIGWIDGET_H
 
 #include <QWidget>
+#include <mailtransport_export.h>
 
 class KConfigDialogManager;
 
@@ -52,7 +40,7 @@ class TransportConfigWidgetPrivate;
   @author Constantin Berzan <exit3219@gmail.com>
   @since 4.4
 */
-class TransportConfigWidget : public QWidget
+class MAILTRANSPORT_EXPORT TransportConfigWidget : public QWidget
 {
     Q_OBJECT
 
@@ -68,7 +56,7 @@ public:
     /**
       Destroys the widget.
     */
-    virtual ~TransportConfigWidget();
+    ~TransportConfigWidget() override;
 
     /**
       @internal
